Documentation
¶
Overview ¶
Package openapi provides primitives to interact with the openapi HTTP API.
Code generated by github.com/oapi-codegen/oapi-codegen/v2 version (devel) DO NOT EDIT.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthJSONBody ¶
type AuthJSONBody struct {
// Secret A secret and unique user identifier. This secret is generated once and never changes. It is used to both authenticate and identify a user, so it should be kept secret.
Secret UserSecret `json:"secret"`
}
AuthJSONBody defines parameters for Auth.
type AuthJSONRequestBody ¶
type AuthJSONRequestBody AuthJSONBody
AuthJSONRequestBody defines body for Auth for application/json ContentType.
type AuthParams ¶
type AuthParams struct {
// UserAgent The user agent of the client making the request.
UserAgent *string `json:"User-Agent,omitempty"`
}
AuthParams defines parameters for Auth.
type DeleteUserSessionParams ¶
type DeleteUserSessionParams struct {
ID int64 `form:"id" json:"id"`
}
DeleteUserSessionParams defines parameters for DeleteUserSession.
type RegisterJSONBody ¶
type RegisterJSONBody struct {
// Name The name to register with
Name string `json:"name"`
}
RegisterJSONBody defines parameters for Register.
type RegisterJSONRequestBody ¶
type RegisterJSONRequestBody RegisterJSONBody
RegisterJSONRequestBody defines body for Register for application/json ContentType.
type Session ¶
type Session struct {
// ID The session identifier
ID int64 `json:"id"`
// CreatedAt The time the session was created
CreatedAt time.Time `json:"createdAt"`
// LastUsed The last time the session was used
LastUsed time.Time `json:"lastUsed"`
// ExpiresAt The time the session expires, or null if it never expires
ExpiresAt time.Time `json:"expiresAt,omitempty"`
}
Session A session for a user.
type User ¶
type User struct {
// Name The user's name
Name string `json:"name"`
// Locale A locale identifier.
Locale Locale `json:"locale"`
}
User A user of the system.
type UserSecret ¶
UserSecret A secret and unique user identifier. This secret is generated once and never changes. It is used to both authenticate and identify a user, so it should be kept secret.